"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const widgets_1 = require("@phosphor/widgets");
const cells_1 = require("@jupyterlab/cells");
const codeeditor_1 = require("@jupyterlab/codeeditor");
const codemirror_1 = require("@jupyterlab/codemirror");
// import {POWERPOINT_TOOL_CLASS, POWERPOINT_TOOL_EDITOR_CLASS} from "./utils";
const utils_1 = require("./utils");
/**
 * Widget holding the Powerpoint widget, container for options and editor
 *
 * @class      PowerpointWidget (name)
 */
// tslint:disable-next-line:max-classes-per-file
class PowerpointWidget extends widgets_1.Widget {
    constructor() {
        super();
        this.currentActiveCell = null;
        this.notebookTracker = null;
        this.editor = null;
        this.node.classList.add(utils_1.POWERPOINT_TOOL_CLASS);
        /* create layout */
        const layout = (this.layout = new widgets_1.PanelLayout());
        /* create codemirror editor */
        const editorOptions = { model: new cells_1.CodeCellModel({}), factory: codemirror_1.editorServices.factoryService.newInlineEditor };
        const editor = (this.editor = new codeeditor_1.CodeEditorWrapper(editorOptions));
        editor.addClass(utils_1.POWERPOINT_TOOL_EDITOR_CLASS);
        editor.model.mimeType = "application/json";
        editor.model.value.changed.connect(() => {
            try {
                JSON.parse(this.editor.model.value.text);
                editor.removeClass(utils_1.POWERPOINT_TOOL_EDITOR_CLASS_INVALID);
                this.saveActiveCell();
            }
            catch (e) {
                editor.addClass(utils_1.POWERPOINT_TOOL_EDITOR_CLASS_INVALID);
            }
        }, this);
        layout.addWidget(editor);
    }
    fetchAndSet() {
        try {
            const json = JSON.parse(this.editor.model.value.text);
            this.currentActiveCell.model.metadata.set("jupyterlab_powerpoint", json);
        }
        catch (e) {
            // tslint:disable-next-line: no-console
            console.warn("invalid JSON");
        }
    }
    loadActiveCell() {
        if (this.currentActiveCell !== null) {
            const metadata = this.currentActiveCell.model.metadata.get("jupyterlab_powerpoint") || {};
            this.editor.model.value.text = JSON.stringify(metadata, null, "\t");
        }
    }
    saveActiveCell() {
        /* if currentActiveCell exists */
        if (this.currentActiveCell !== null) {
            try {
                const json = JSON.parse(this.editor.model.value.text);
                this.currentActiveCell.model.metadata.set("jupyterlab_powerpoint", json);
            }
            catch (e) {
                // tslint:disable-next-line: no-console
                console.warn("invalid JSON");
            }
        }
    }
    deleteActiveCell() {
        if (this.currentActiveCell !== null) {
            this.currentActiveCell.model.metadata.delete("jupyterlab_powerpoint");
        }
    }
    get editorWidget() {
        return this.editor;
    }
}
exports.PowerpointWidget = PowerpointWidget;
